@@ -13,9 +13,11 @@ from src.amarium.utils import (
     make_full_filename,
     save_json_to_file,
     search_subdirs,
+    write_txt_file,
     attach_slash,
     delete_file,
     write_tar,
+    read_file,
     copy_dir,
 )
 
@@ -23,7 +25,6 @@ from src.amarium.checks import check_make_file_name_suffix, check_make_dir
 
 
 def test_delete_file():
-
     file_name = "./tests/empty.txt"
     with pytest.raises(Exception) as e:
         delete_file(file_name)
@@ -98,18 +99,15 @@ def test_make_full_name():
 
 
 def test_prepare_file_name_saving():
-
     # case 1
     test_dir = "tests/data"
     name = "test_file_name_saving"
     suffix = ".txt"
-    file_name = prepare_file_name_saving(
-        prefix=test_dir, file_name=name, suffix=suffix)
+    file_name = prepare_file_name_saving(prefix=test_dir, file_name=name, suffix=suffix)
     assert file_name == "tests/data/test_file_name_saving.txt"
     # case 2
     test_dir = "tests/data/"
-    file_name = prepare_file_name_saving(
-        prefix=test_dir, file_name=name, suffix=suffix)
+    file_name = prepare_file_name_saving(prefix=test_dir, file_name=name, suffix=suffix)
     assert file_name == "tests/data/test_file_name_saving.txt"
     # case 3
     file_name = "tests/data/test_file_name_saving.txt"
@@ -119,7 +117,6 @@ def test_prepare_file_name_saving():
 
 def test_insert_string_in_file_name():
     def make_name(file_name, insertions, suffix, expectation):
-
         new_file_name = insert_string_in_file_name(
             file_name=file_name, insertion=insertion, suffix=suffix
         )
@@ -137,8 +134,7 @@ def test_insert_string_in_file_name():
     insertion = "fantastic"
     suffix = None
     expectation = "foo_fantastic.bar"
-    result_name = make_name(file_name, insertion,
-                            suffix, expectation=expectation)
+    result_name = make_name(file_name, insertion, suffix, expectation=expectation)
 
     # case2
     file_name = "foo"
@@ -244,7 +240,6 @@ def test_search_subdir():
 
 
 def test_tar_writer():
-
     target_dir = "tests/test_dir_search"
     file_name = "tests/test.tar"
     write_tar(target_dir=target_dir, file_name=file_name)
@@ -254,7 +249,6 @@ def test_tar_writer():
 
 
 def test_copy_dir():
-
     import shutil
 
     target_dir = "tests/test_dir_copy"
@@ -266,7 +260,6 @@ def test_copy_dir():
 
 
 def test_str_convert_to_bool():
-
     test_string = "False"
     test_bool = convert_str_to_bool(test_string)
     assert test_bool is False
@@ -276,7 +269,6 @@ def test_str_convert_to_bool():
 
 
 def test_make_date_file_name():
-
     time_str = time.strftime("%Y%m%d-%H%M%S")
     date_file_name = make_date_file_name(prefix="", file_name="", suffix="")  #
     assert (
@@ -285,11 +277,42 @@ def test_make_date_file_name():
 
 
 def test_attach_string():
-
-    test_string ="test_dir_or_file"
+    test_string = "test_dir_or_file"
     test_string_mod = attach_slash(test_string)
     assert test_string_mod == test_string + "/"
 
     test_string = "test_dir_or_file/"
     test_string_mod = attach_slash(test_string)
-    assert test_string_mod == test_string
\ No newline at end of file
+    assert test_string_mod == test_string
+
+
+def test_read_file():
+    test_string = "Testing a txt write file"
+    file_name = "tests/test_files/test.txt"
+    write_txt_file(content=test_string, file_name=file_name, encoding="utf-8")
+    res_content = read_file(file_name=file_name, encoding="utf-8")
+    assert res_content == test_string
+    delete_file(file_name=file_name)
+
+
+def test_write_txt():
+    test_string = "Testing a txt write file"
+    file_name = "tests/test_files/test.txt"
+    write_txt_file(content=test_string, file_name=file_name, encoding="utf-8")
+    res_content = read_file(file_name=file_name, encoding="utf-8")
+    assert res_content == test_string
+    delete_file(file_name=file_name)
+
+    test_string = "Testing a txt write file"
+    file_name = "tests/test_files/test.txt"
+    write_txt_file(content=test_string, file_name=file_name)
+    res_content = read_file(file_name=file_name)
+    assert res_content == test_string
+    delete_file(file_name=file_name)
+
+    test_string = "Testing a txt write file"
+    file_name = "tests/non_existent_folder/test.txt"
+    write_txt_file(content=test_string, file_name=file_name)
+    res_content = read_file(file_name=file_name)
+    assert res_content == test_string
+    delete_file(file_name=file_name)
\ No newline at end of file
